==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/installer/messages/tr/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Yönetici</strong> Hesabı',
    '<strong>Configuration</strong>' => '<strong>Yapılandırma</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Tebrikler</strong> tüm adımları tamamladınız.',
    '<strong>Database</strong> Configuration' => '<strong>Veritabanı</strong> Ayarlamaları',
    '<strong>Example</strong> contents' => '<strong>Örnek</strong> içerik',
    '<strong>System</strong> Check' => '<strong>Sistem</strong> Kontrol',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Humhub</strong>\'a hoşgeldiniz<br />Sosyal Ağınız',
    'Allow access for non-registered users to public content (guest access)' => 'Kayıtlı olmayan kullanıcıların herkese açık içeriğe erişmesine izin ver (misafir erişimi)',
    'Allow friendships between members' => 'Üyeler arasında arkadaşlıklara izin ver',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Veritabanı bağlantı ayarlarını girmek zorundasınız. Bu konuda emin değilseniz sistem yöneticinize başvurun.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein – Aşk ve çılgınlık arasında saplantıdır.',
    'Check again' => 'Kontrol Et',
    'Congratulations! Everything is ok and ready to start over!' => 'Tebrik ederiz! Her şey tamam ve kuruluma başlamak için hazır!',
    'Create Admin Account' => 'Yönetici Hesabı Oluştur',
    'Downloading & Installing Modules...' => 'Modülleri İndirme ve Yükleme ...',
    'External users can register (show registration form on login)' => 'Harici kullanıcılar kayıt olabilir (girişte kayıt formunu göster)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Burada kayıtlı olmayan yeni kullanıcıların HumHub\'a nasıl erişebileceğine karar verebilirsiniz.',
    'Hostname' => 'Host adı (Örnek: localhost)',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQL veritabanı sunucusu ana bilgisayar adı (örneğin, localhost MySQL aynı makinede çalışıyorsa)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub çok esnektir ve farklı modülleri sayesinde farklı uygulamalar için ayarlanabilir veya genişletilebilir. Aşağıdaki modüller sadece birkaç örnek ve seçtiğiniz uygulama için en önemli olduğunu düşündüklerimizdir. <br /><br /> Modülleri istediğiniz zaman kurabilir veya kaldırabilirsiniz. Kurulumdan sonra yönetici sayfasından daha fazla modül bulabilirsiniz.',
    'I want to use HumHub for:' => 'Humhub kullanmak isteğiniz nedir:',
    'Initializing database...' => 'Veritabanı başlatılıyor...',
    'My club' => 'Benim kulübüm',
    'My community' => 'Benim topluluğum',
    'My company (Social Intranet / Project management)' => 'Şirketim (Sosyal Intranet / Proje yönetimi)',
    'My educational institution (school, university)' => 'Eğitim kurumum (okul, üniversite)',
    'Name of Database' => 'Database Adı',
    'Name of your network' => 'Sosyal Ağınızın Adı',
    'Newly registered users have to be activated by an admin first' => 'Yeni kayıtlı kullanıcılar önce bir yönetici tarafından aktif hale getirilmelidir',
    'Next' => 'İleri',
    'Nike – Just buy it. :wink:' => 'Nike – Sadece al. :wink:',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Yeni sosyal ağınızın bir ismi olmalı. Lütfen varsayılan adı istediğiniz gibi değiştiriniz. (ör: şirket, kuruluş veya kulüp adı)',
    'Ohh, something went wrong!' => 'Ohh, bir şeyler yanlış gitti!',
    'Password' => 'Şifre',
    'Port' => 'Port',
    'Recommended <strong>Modules</strong>' => 'Önerilen <strong>Modüller</strong>',
    'Registered members can invite new users via email' => 'Kayıtlı üyeler yeni kullanıcıları e-postayla davet edebilir',
    'Security <strong>Settings</strong>' => '<strong>Güvenlik</strong> ayarları',
    'Set up example content (recommended)' => 'Örnek içerikleri ayarlayın(Önerilen)',
    'Sign in' => 'Giriş Yap',
    'Skip this step, I want to set up everything manually' => 'Bu adımı atla, el ile her şeyi kurmak istiyorum',
    'Social Network <strong>Name</strong>' => 'Sosyal Ağ <strong>Adı</strong>',
    'The installation completed successfully! Have fun with your new social network.' => 'Kurulum başarıyla tamamlandı! <br /> Yeni sosyal ağınızla paylaşım yapmaya başlayabilirsiniz.',
    'The name of the database you want to run HumHub in.' => 'Humhub kurulumu için çalışmak istediğiniz veritabanı adı.',
    'This overview shows all system requirements of HumHub.' => 'HumHub sistem gereksinimlerinizin uygun olup olmadığını gösterir.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Kurulum sihirbazı ile kendi Humhub Sosyal Ağınızı oluşturabilirsiniz.<br />Devam etmek için İleri\'ye tıklayın.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'İlk girişinizden sonra HumHub sizin için örnek içerik panosunu yükler. Bu, HumHub\'un nasıl çalıştığına dair genel bir bakış açısı verecektir. Bireysel içeriği her zaman silebilirsiniz.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Yapılandırmayı basitleştirmek için, modüller ve ayarlar için farklı seçenekler sunan en yaygın kullanım durumları için önceden tanımlanmış kurulumlar vardır. Bir sonraki adımda bunları ayarlayabilirsiniz.',
    'Username' => 'Kullanıcı adı',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Ünlü markaların harika sloganlarını arıyoruz. Belki bazı örnekler ile gelebilirsin?',
    'Welcome Space' => 'Karşılama Mekanı',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Yuppi! Az önce HumHub\'ı kurdum :sunglasses:',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Neredeyse bitti. Bu adımda bir yönetici hesabı oluşturmak için formu doldurmanız gerekmektedir. Bu hesapla tüm sosyal ağı yönetebilirsiniz.',
    'Your MySQL password.' => 'MySQL şifre',
    'Your MySQL username' => 'MySQL kullanıcı adı',
    'Your first sample space to discover the platform.' => 'Platformu keşfetmek için ilk örnek mekanınız.',
    '<strong>Pretty URLs</strong> configuration' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => '',
    'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => '',
    'Registered members can invite new users via link' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/installer/messages/tr/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Yönetici</strong> Hesabı',
    '<strong>Configuration</strong>' => '<strong>Yapılandırma</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Tebrikler</strong> tüm adımları tamamladınız.',
    '<strong>Database</strong> Configuration' => '<strong>Veritabanı</strong> Ayarlamaları',
    '<strong>Example</strong> contents' => '<strong>Örnek</strong> içerik',
    '<strong>System</strong> Check' => '<strong>Sistem</strong> Kontrol',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Humhub</strong>\'a hoşgeldiniz<br />Sosyal Ağınız',
    'Allow access for non-registered users to public content (guest access)' => 'Kayıtlı olmayan kullanıcıların herkese açık içeriğe erişmesine izin ver (misafir erişimi)',
    'Allow friendships between members' => 'Üyeler arasında arkadaşlıklara izin ver',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Veritabanı bağlantı ayarlarını girmek zorundasınız. Bu konuda emin değilseniz sistem yöneticinize başvurun.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Calvin Klein – Aşk ve çılgınlık arasında saplantıdır.',
    'Check again' => 'Kontrol Et',
    'Congratulations! Everything is ok and ready to start over!' => 'Tebrik ederiz! Her şey tamam ve kuruluma başlamak için hazır!',
    'Create Admin Account' => 'Yönetici Hesabı Oluştur',
    'Downloading & Installing Modules...' => 'Modülleri İndirme ve Yükleme ...',
    'External users can register (show registration form on login)' => 'Harici kullanıcılar kayıt olabilir (girişte kayıt formunu göster)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Burada kayıtlı olmayan yeni kullanıcıların HumHub\'a nasıl erişebileceğine karar verebilirsiniz.',
    'Hostname' => 'Host adı (Örnek: localhost)',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQL veritabanı sunucusu ana bilgisayar adı (örneğin, localhost MySQL aynı makinede çalışıyorsa)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub çok esnektir ve farklı modülleri sayesinde farklı uygulamalar için ayarlanabilir veya genişletilebilir. Aşağıdaki modüller sadece birkaç örnek ve seçtiğiniz uygulama için en önemli olduğunu düşündüklerimizdir. <br /><br /> Modülleri istediğiniz zaman kurabilir veya kaldırabilirsiniz. Kurulumdan sonra yönetici sayfasından daha fazla modül bulabilirsiniz.',
    'I want to use HumHub for:' => 'Humhub kullanmak isteğiniz nedir:',
    'Initializing database...' => 'Veritabanı başlatılıyor...',
    'My club' => 'Benim kulübüm',
    'My community' => 'Benim topluluğum',
    'My company (Social Intranet / Project management)' => 'Şirketim (Sosyal Intranet / Proje yönetimi)',
    'My educational institution (school, university)' => 'Eğitim kurumum (okul, üniversite)',
    'Name of Database' => 'Database Adı',
    'Name of your network' => 'Sosyal Ağınızın Adı',
    'Newly registered users have to be activated by an admin first' => 'Yeni kayıtlı kullanıcılar önce bir yönetici tarafından aktif hale getirilmelidir',
    'Next' => 'İleri',
    'Nike – Just buy it. :wink:' => 'Nike – Sadece al. :wink:',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Yeni sosyal ağınızın bir ismi olmalı. Lütfen varsayılan adı istediğiniz gibi değiştiriniz. (ör: şirket, kuruluş veya kulüp adı)',
    'Ohh, something went wrong!' => 'Ohh, bir şeyler yanlış gitti!',
    'Password' => 'Şifre',
    'Port' => 'Port',
    'Recommended <strong>Modules</strong>' => 'Önerilen <strong>Modüller</strong>',
    'Registered members can invite new users via email' => 'Kayıtlı üyeler yeni kullanıcıları e-postayla davet edebilir',
    'Security <strong>Settings</strong>' => '<strong>Güvenlik</strong> ayarları',
    'Set up example content (recommended)' => 'Örnek içerikleri ayarlayın(Önerilen)',
    'Sign in' => 'Giriş Yap',
    'Skip this step, I want to set up everything manually' => 'Bu adımı atla, el ile her şeyi kurmak istiyorum',
    'Social Network <strong>Name</strong>' => 'Sosyal Ağ <strong>Adı</strong>',
    'The installation completed successfully! Have fun with your new social network.' => 'Kurulum başarıyla tamamlandı! <br /> Yeni sosyal ağınızla paylaşım yapmaya başlayabilirsiniz.',
    'The name of the database you want to run HumHub in.' => 'Humhub kurulumu için çalışmak istediğiniz veritabanı adı.',
    'This overview shows all system requirements of HumHub.' => 'HumHub sistem gereksinimlerinizin uygun olup olmadığını gösterir.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Kurulum sihirbazı ile kendi Humhub Sosyal Ağınızı oluşturabilirsiniz.<br />Devam etmek için İleri\'ye tıklayın.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'İlk girişinizden sonra HumHub sizin için örnek içerik panosunu yükler. Bu, HumHub\'un nasıl çalıştığına dair genel bir bakış açısı verecektir. Bireysel içeriği her zaman silebilirsiniz.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Yapılandırmayı basitleştirmek için, modüller ve ayarlar için farklı seçenekler sunan en yaygın kullanım durumları için önceden tanımlanmış kurulumlar vardır. Bir sonraki adımda bunları ayarlayabilirsiniz.',
    'Username' => 'Kullanıcı adı',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Ünlü markaların harika sloganlarını arıyoruz. Belki bazı örnekler ile gelebilirsin?',
    'Welcome Space' => 'Karşılama Mekanı',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Yuppi! Az önce HumHub\'ı kurdum :sunglasses:',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Neredeyse bitti. Bu adımda bir yönetici hesabı oluşturmak için formu doldurmanız gerekmektedir. Bu hesapla tüm sosyal ağı yönetebilirsiniz.',
    'Your MySQL password.' => 'MySQL şifre',
    'Your MySQL username' => 'MySQL kullanıcı adı',
    'Your first sample space to discover the platform.' => 'Platformu keşfetmek için ilk örnek mekanınız.',
    '<strong>Apache</strong> web server detected.' => '',
    '<strong>Nginx</strong> web server detected.' => '',
    '<strong>Pretty URLs</strong>' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'Ensure the following rule is present in your configuration: <strong>try_files $uri $uri/ /index.php?$args;</strong>.' => '',
    'For more information on this topic, please refer to our <a href="{link}" target="_blank">documentation</a>.' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In the installation folder, locate the <strong>.env.example</strong> file and copy its contents into the <strong>.env</strong> file. Next, find the <strong>Pretty URLs</strong> block and uncomment it by removing the <strong>#</strong> symbol.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'Make sure that the following file is writable: thi' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Pretty URLs may not work correctly.' => '',
    'Pretty URLs should work correctly.' => '',
    'Registered members can invite new users via link' => '',
    'The <strong>.htaccess</strong> file is in place.' => '',
    'The <strong>.htaccess</strong> file is not in place. In the installation folder, locate the <strong>.htaccess.dist</strong> file and rename it to <strong>.htaccess</strong>.' => '',
    'The <strong>mod_rewrite</strong> module is active.' => '',
    'The <strong>mod_rewrite</strong> module is not enabled.' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
    'Unable to automatically detect your web server type. Please ensure URL rewriting is configured.' => '',
];
